@@ -7,7 +7,7 @@
 #modality vector of ddl
 
 waldtest <- function(N,nfact,place,modality,b,Varb,Lfirts=NULL,Llast=NULL,Ntot=NULL){
-	waldValue <- rep(0,nfact)	
+	waldValue <- rep(0,nfact)
 	for(i in 1:nfact){
 		if(place[i] == 1){
 			taillecol <- N-modality[i]
@@ -35,12 +35,12 @@ waldtest <- function(N,nfact,place,modality,b,Varb,Lfirts=NULL,Llast=NULL,Ntot=N
 			if(!is.null(Lfirts)) L <- cbind(matrix(0,nrow=modality[i],ncol=Lfirts),L)
 			if(!is.null(Llast)) L <- cbind(L,matrix(0,nrow=modality[i],ncol=Llast))
 		}
-		W <- 0
-		r = dim(L)[1]
-		W = t(L%*%b) %*% solve(L%*%Varb%*%t(L)) %*% (L%*%b)
+		#W <- 0
+		#r = dim(L)[1]
+		#W = t(L%*%b) %*% solve(L%*%Varb%*%t(L)) %*% (L%*%b)
 		# W = t(L%*%b) %*% (L%*%(Varb%*%t(L))) %*% (L%*%b)
-		W = as.numeric(W)
-		waldValue[i] = W 
+		#W = as.numeric(W)
+		#waldValue[i] = W 
 		
 		# cat('en R \n : b')
 		# print(b)
@@ -51,17 +51,17 @@ waldtest <- function(N,nfact,place,modality,b,Varb,Lfirts=NULL,Llast=NULL,Ntot=N
 		
 		# cat('En fortran\n')
 		
-		# if(is.null(Ntot))Ntot <- N
-		# out <- .Fortran("waldmultiv",
-				# as.double(b),
-				# as.integer(Ntot),
-				# as.integer(L),
-				# as.double(Varb),
-				# as.integer(modality[i]),
-				# Wald=as.double(0),
-				# PACKAGE = "frailtypack")
-		 # waldValue[i] <- out$Wald
-	# #		print(L)
+		if(is.null(Ntot))Ntot <- N
+		out <- .Fortran("waldmultiv",
+				as.double(b),
+				as.integer(Ntot),
+				as.integer(L),
+				as.double(Varb),
+				as.integer(modality[i]),
+				Wald=as.double(0),
+				PACKAGE = "frailtypack")
+		waldValue[i] <- out$Wald
+#		print(L)
 	}
 	return(waldValue)
 }# end Wald
